##################
User documentation
##################

.. toctree::
   :maxdepth: 3

   How to get started <Users-Guide>
   Creating a timeline <Creating-a-timeline>
   Using collection Filters <Collection-Filters>
   Event filters <Event-filters>
   Analysis plugins <Analysis-plugins>
   Tips and Tricks <Tips-and-Tricks>
   Troubleshooting <Troubleshooting>
   Feature requests and bug reports <Feature-requests-and-bug-reports>
   Log2Timeline Perl (Legacy) <Log2Timeline-Perl-(Legacy)>
